<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Admin;
use App\Models\Country;
use App\Repositories\AdminsRepository;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;


class AdminsController extends Controller
{


    public function index()
    {


        $rows = Admin::all();
        return view('admin.admin.index', compact('rows'));
    }


    public function create()
    {

        return view('admin.admin.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required|max:191',
            'email' => 'required|email|unique:admins,email|max:191',
            'mobile' => 'required|unique:admins,mobile|max:191',
            'password' => 'required|min:6|max:191',

        ]);
        $admin = new Admin();
        $admin->name = $request['name'];
        $admin->mobile = $request['mobile'];
        $admin->email = $request['email'];
        $admin->password = bcrypt($request['password']);
        $admin->save();


        success_toast();
        return redirect()->route('admins.index');

    }


    public function edit($id)
    {
        $row = Admin::findOrFail($id);


        return view('admin.admin.edit', compact('row'));
    }


    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required|max:191',
            'email' => 'required|max:191|email|unique:admins,email,' . $id,
            'mobile' => 'max:191|required|unique:admins,mobile,' . $id,
            'password' => 'nullable|min:6|max:191',
        ]);
        $admin = Admin::findOrFail($id);
        $admin->name = $request['name'];
        $admin->mobile = $request['mobile'];
        $admin->email = $request['email'];
        if ($request->password) $admin->password = bcrypt($request['password']);
        $admin->update();


        success_toast();
        return redirect()->route('admins.index');

    }


    public function destroy($id)
    {
        $adminCounts = Admin::count();
        if ($adminCounts == 1) {
            Alert::error('عفوا لا يمكن حذف أخر مدير');
            return back();
        } else {
            Admin::destroy($id);
            success_toast();
            return back();
        }
    }
}
