<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Level;
use Illuminate\Http\Request;

class LevelsController extends Controller
{
    public function index()
    {
        $rows = Level::all();
        return view('admin.levels.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.levels.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required|max:191',
            'lowest_rang' => 'required|numeric',
            'highest_rang' => 'required|numeric|gte:lowest_rang',
            'client_point' => 'required|numeric',
            'merchant_point' => 'required|numeric',
        ]);
        Level::create($request->all());
        success_toast();
        return redirect()->route('levels.index');
    }

    public function edit($id)
    {
        $row = Level::findOrFail($id);
        return view('admin.levels.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'title' => 'required|max:191',
            'lowest_rang' => 'required|numeric',
            'highest_rang' => 'required|numeric|gte:lowest_rang',
            'client_point' => 'required|numeric',
            'merchant_point' => 'required|numeric',
        ]);
        Level::whereId($id)->update($request->except('_token', '_method'));
        success_toast();
        return redirect()->route('levels.index');
    }

    public function destroy($id)
    {
        Level::destroy($id);
        success_toast();
        return redirect()->route('levels.index');
    }
}
