<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\PointProduct;
use App\Models\PointProductImage;
use Illuminate\Http\Request;

class PointProductsController extends Controller
{
    public function index()
    {
        $rows = PointProduct::all();
        return view('admin.point_products.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.point_products.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required|max:191',
            'client_point' => 'required|numeric|max:191',
            'merchant_point' => 'required|numeric|max:191',
            'count' => 'required|numeric|max:191',
            'description' => 'required',
            'point_product_images' => 'required|array'
        ]);
      $product =  PointProduct::create($request->all());

        foreach ($request->point_product_images as $point_product_image) {
            $image = new PointProductImage();
            $image->setImageAttribute($point_product_image);
            $image->point_product_id = $product->id;
            $image->save();
        }

        success_toast();
        return redirect()->route('point_products.index');
    }

    public function edit($id)
    {
        $row = PointProduct::findOrFail($id);
        return view('admin.point_products.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'title' => 'required|max:191',
            'client_point' => 'required|numeric|max:191',
            'merchant_point' => 'required|numeric|max:191',
            'count' => 'required|numeric|max:191',
            'description' => 'required'
        ]);
        $product = PointProduct::whereId($id)->update($request->except('_method', '_token'));

        if ($request->point_product_images) {
            foreach ($request->point_product_images as $point_product_image) {
                $image = new PointProductImage();
                $image->setImageAttribute();
                $image->point_product_id = $product->id;
                $image->save();
            }
        }
        success_toast();
        return redirect()->route('point_products.index');
    }


    public function destroy_image($id)
    {
        PointProductImage::destroy($id);
        success_toast();
        return back();
    }

    public function destroy($id)
    {
        PointProduct::destroy($id);
        success_toast();
        return back();
    }
}
