<?php

namespace App\Http\Controllers\Site;

use App\Http\Controllers\Controller;
use App\Models\Cart;
use App\Models\Product;
use App\Models\Setting;
use Illuminate\Http\Request;

class CartsController extends Controller
{

    public function add_product_to_cart(Request $request)
    {
        $this->validate($request, [
            'product_id' => 'required|exists:products,id',
            'count' => 'required'
        ]);
        $product = Product::find($request->product_id);
        $cart_product = Cart::where(['user_id' => \Auth::user()->id, 'product_id' => $request->product_id, 'status' => 'cart'])->first();
        if ($cart_product) {
            $all_count = $cart_product->count + $request->count;
        } else {
            $all_count = $request->count;
        }

        if ($all_count == 0) {
            alert('خطأ', 'لا يمكن اختيار الكميه 0', 'error');
            return redirect()->back();
        } elseif ($all_count > $product->count) {
            alert('خطأ', 'عفوا هذه الكمية غير متاحة', 'error');
            return redirect()->back();
        }


        if (\Auth::user()->type == 'client') {
            $price = $product->client_price;
        } else {
            $price = $product->merchant_price;
        }


        if (!$cart_product) {
            $cart = new Cart();
            $cart->user_id = \Auth::user()->id;
            $cart->product_id = $request->product_id;
            $cart->count = $request->count;
            $cart->total_price = $price * $request->count;
            $cart->status = 'cart';
            $cart->save();
            alert('الاضافه الى السلة', 'تم اضافه المنتج الى السلة بنجاح', 'success');
            return redirect()->back();
        } else {
            $cart = Cart::find($cart_product->id);
            $count = $cart->count + $request->count;
            $cart->count = $count;
            $cart->total_price = $price * $count;
            $cart->update();

        }
        alert('تعديل السلة', 'تم اضافه المنتج وتعديل كميته فى السلة بنجاح', 'success');
        return redirect()->back();
    }

    public function my_cart()
    {
        $rows = \Auth::user()->carts()->where(['status' => 'cart'])->get();
        $tax = Setting::first()->value('tax') ? Setting::first()->value('tax') : 0;
        $total_price_products = Cart::where(['status' => 'cart', 'user_id' => \Auth::user()->id])->sum('total_price');
        $products_tax = $total_price_products * $tax / 100;
        $total_price_products_tax = $total_price_products + $products_tax;
        return view('site.carts.cart', compact('rows', 'tax', 'total_price_products', 'total_price_products_tax'));
    }

    public function delete_cart($id)
    {
        $cart = Cart::find($id);
        $cart->delete();
        toast('تم مسح المنتج من السلة', 'success');
        return redirect()->back();
    }


    public function update_cart_ajax(Request $request)
    {
        $count = $request->count;

        $tax = Setting::first()->value('tax') ? Setting::first()->value('tax') : 0;
        $cart = Cart::find($request->id);
        $product = Product::find($cart->product_id);

        if ($count == 0) {
            return response()->json(['value' => false, 'msg' => 'لا يمكن اختيار الكميه 0', 'count' => $cart->count]);
        }
        if ($request->type == 'plus') {
            if ($count > $product->count) {
                return response()->json(['value' => false, 'msg' => 'غير متوفر هذه الكميه فى المنتج', 'count' => $cart->count]);
            }
        }
        if ($count > $product->count) {
            $type = 'false';
        } else {
            $type = 'true';
        }
        if (\Auth::user()->type == 'client') {
            $price = $product->client_price;
        } else {
            $price = $product->merchant_price;
        }
        $cart->count = $count;

        $cart->total_price = $price * $count;
        $cart->update();
        $total_price = $cart->total_price . ' ريال';
        $total_price_products = Cart::where(['user_id' => \Auth::user()->id, 'status' => 'cart'])->sum('total_price');
        $products_tax = $total_price_products * $tax / 100;
        $total_price_products_tax = $total_price_products + $products_tax;

        return response()->json(['value' => true, 'total_price' => $total_price, 'total_price_products' => $total_price_products . ' ريال', 'total_price_products_tax' => $total_price_products_tax . ' ريال', 'type' => $type, 'tax' => $tax . ' %']);
    }


}
