<?php

namespace App\Http\Controllers\Site;

use App\Http\Controllers\Controller;
use App\Mail\ProductCardsMail;
use App\Models\Bank;
use App\Models\Cart;
use App\Models\Notification;
use App\Models\Order;
use App\Models\OrderCard;
use App\Models\OrderCart;
use App\Models\PointCart;
use App\Models\PointProduct;
use App\Models\Product;
use App\Models\ProductCard;
use App\Models\Setting;
use App\Models\User;
use Illuminate\Http\Request;

class OrderControllers extends Controller
{

    public function order_finished()
    {
        $carts = Cart::where(['user_id' => \Auth::user()->id, 'status' => 'order'])->whereHas('orders', function ($q) {
            $q->where('status', 'finished');
        })->pluck('product_id');

        $rows = Product::whereIn('id', array_unique($carts->toArray()))->paginate(12);
        return view('site.payments.order_finished', compact('rows'));
    }

    public function point_order_finished()
    {
        $carts = PointCart::where(['user_id' => \Auth::user()->id, 'status' => 'order'])->whereHas('orders', function ($q) {
            $q->where('status', 'finished');
        })->pluck('point_product_id');

        $point_rows = PointProduct::whereIn('id', array_unique($carts->toArray()))->paginate(12);
        return view('site.payments.point_order_finished', compact('point_rows'));
    }

    public function order_wallet()
    {
        $carts = \Auth::user()->carts()->where('status', 'cart')->get();
        $tax = Setting::first()->value('tax') ? Setting::first()->value('tax') : 0;
        $total_price_products = Cart::where(['status' => 'cart', 'user_id' => \Auth::user()->id])->sum('total_price');
        $products_tax = $total_price_products * $tax / 100;
        $total_price_products_tax = $total_price_products + $products_tax;
        if ($carts) {
            foreach ($carts as $cart) {
                if ($cart->pivot->count > $cart->count) {
                    alert('خطأ', 'بعض المنتجات اصبحت غير متاحه', 'error');
                    return redirect()->back();
                }
            }
            return view('site.payments.order_wallet', compact('total_price_products_tax'));
        }
        return redirect()->back();
    }

    public function pay_order_wallet()
    {
        $carts = \Auth::user()->carts()->where('status', 'cart')->get();
        $tax = Setting::first()->value('tax') ? Setting::first()->value('tax') : 0;
        $total_price_products = Cart::where(['status' => 'cart', 'user_id' => \Auth::user()->id])->sum('total_price');
        $products_tax = $total_price_products * $tax / 100;
        $total_price_products_tax = $total_price_products + $products_tax;
        if ($total_price_products_tax > \Auth::user()->wallet) {
            alert('خطأ', 'رصيدك غير كافى برجاء شحن المحفظة', 'error');
            return redirect()->back();
        }

        $order = new Order();
        $order->user_id = \Auth::user()->id;
        $order->payment_method = 'wallet';
        $order->total_price = $total_price_products_tax;
        $order->tax = $tax;
        $order->status = 'new';
        $order->save();

        $products = array();
        $i = 1;
        foreach ($carts as $cart) {
            if ($cart->online_card == 'true') {
                $products[$i] = new \stdClass();
                $products[$i]->title = $cart->title;

                $product_cards = ProductCard::where(['available' => 'true', 'product_id' => $cart->id])->take($cart->pivot->count)->get();

                foreach ($product_cards as $product_card) {
                    $order_card = new OrderCard();
                    $order_card->product_card_id = $product_card->id;
                    $order_card->order_id = $order->id;
                    $order_card->save();

                    $card = ProductCard::find($product_card->id);
                    $card->available = 'false';
                    $card->update();

                    $products[$i]->card_code[] = $product_card->card_code;

                }

            }

            $order_cart = new OrderCart();
            $order_cart->cart_id = $cart->pivot->id;
            $order_cart->order_id = $order->id;
            $order_cart->save();

            $update_cart = Cart::find($cart->pivot->id);
            $update_cart->status = 'order';
            $update_cart->update();


            $product = Product::find($cart->id);
            $product->count -= $cart->pivot->count;
            $product->update();
            $i++;
        }


        if (isset($products)) {
            \Mail::to(\Auth::user()->email)->send(new ProductCardsMail($products));
            $order->card = 'sent';
            $order->update();

            $notification = new Notification();
            $notification->user_id = $order->user_id;
            $notification->title = "طلب رقم $order->id";
            $notification->description = "تم ارسال الكروت الخاصه بالطلب على البريد الالكترونى الخاص بك";
            $notification->save();

        }


        $wallet = \Auth::user()->wallet - $total_price_products_tax;
        $user = User::find(\Auth::user()->id);
        $user->wallet = $wallet;
        $user->update();

        alert('ارسال', 'تم الدفع بالمحفظة سيصلك اشعار للتأكيد', 'success');
        return redirect()->route('home');

    }

    public function order_bank_transfer()
    {
        $banks = Bank::all();
        $carts = \Auth::user()->carts()->where('status', 'cart')->get();
        if ($carts) {
            foreach ($carts as $cart) {
                if ($cart->pivot->count > $cart->count) {
                    alert('خطأ', 'بعض المنتجات اصبحت غير متاحه', 'error');
                    return redirect()->back();
                }
            }
        }
        return view('site.payments.bank_transfer', compact('banks'));
    }

    public function order_bank_transfer_post(Request $request)
    {
        $this->validate($request, [
            'transfer_name' => 'required|max:191',
            'transfer_number' => 'required|max:191',
            'bank_id' => 'required|exists:banks,id',
            'transfer_iban' => 'required|max:191',
            'transfer_date' => 'required|date',
            'transfer_image' => 'required|image'
        ]);


        $carts = \Auth::user()->carts()->where('status', 'cart')->get();
        $tax = Setting::first()->value('tax') ? Setting::first()->value('tax') : 0;
        $total_price_products = Cart::where(['status' => 'cart', 'user_id' => \Auth::user()->id])->sum('total_price');
        $products_tax = $total_price_products * $tax / 100;
        $total_price_products_tax = $total_price_products + $products_tax;


        $order = new Order();
        $order->user_id = \Auth::user()->id;
        $order->total_price = $total_price_products_tax;
        $order->tax = $tax;
        $order->status = 'waiting';
        $order->payment_method = 'bank';
        $order->transfer_name = $request->transfer_name;
        $order->transfer_number = $request->transfer_number;
        $order->bank_id = $request->bank_id;
        $order->transfer_iban = $request->transfer_iban;
        $order->transfer_date = $request->transfer_date;
        if ($request->hasFile('transfer_image')) $order->setTransferImageAttribute();
        $order->save();


        foreach ($carts as $cart) {

            if ($cart->online_card == 'true') {
                $product_cards = ProductCard::where(['available' => 'true', 'product_id' => $cart->id])->take($cart->pivot->count)->get();


                foreach ($product_cards as $product_card) {
                    $order_card = new OrderCard();
                    $order_card->product_card_id = $product_card->id;
                    $order_card->order_id = $order->id;
                    $order_card->save();

                    $card = ProductCard::find($product_card->id);
                    $card->available = 'false';
                    $card->update();
                }
                $order_cart = new OrderCart();
                $order_cart->cart_id = $cart->pivot->id;
                $order_cart->order_id = $order->id;
                $order_cart->save();
            } else {
                $order_cart = new OrderCart();
                $order_cart->cart_id = $cart->pivot->id;
                $order_cart->order_id = $order->id;
                $order_cart->save();
            }


            $update_cart = Cart::find($cart->pivot->id);
            $update_cart->status = 'order';
            $update_cart->update();


            $product = Product::find($cart->id);
            $product->count -= $cart->pivot->count;
            $product->update();

        }

        if (isset($product_cards)) {
            $order->card = 'true';
            $order->update();
        }

        alert('ارسال', 'تم ارسال التحويل سيصلك اشعار للتأكيد', 'success');
        return redirect()->route('home');

    }


    public function payment()
    {
        //ToDO: $order->card = 'sent';
    }

}
