<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;

class Product extends Model
{

    protected $table = 'products';
    public $timestamps = true;
    protected $fillable = array('title', 'description', 'count', 'category_id', 'client_price', 'merchant_price', 'online_card', 'sale');

    protected $appends = ['price', 'type'];


    public function product_cards()
    {
        return $this->hasMany(ProductCard::class, 'product_id');
    }

    public function category()
    {
        return $this->belongsTo(Category::class, 'category_id');
    }

    public function tags()
    {
        return $this->belongsToMany(Tag::class, 'product_tags', 'product_id', 'tag_id')->withPivot('id');
    }

    public function getPriceAttribute()
    {
        if (\Auth::check() && \Auth::user()->type == 'client' || !\Auth::check()) {
            return $this->client_price . ' ريال ';
        }
        return $this->merchant_price . ' ريال ';
    }

    public function getTypeAttribute()
    {
        $date = Carbon::parse($this->created_at)->addDays(7);
        if ($this->count == 0) {
            return '<span class="sold">sold</span>';
        } elseif ($this->sale == 'true') {
            return '<span class="sold sall">sall</span>';
        } elseif (Carbon::parse($this->created_at) <= $date) {
            return '<span class="sold new">New</span>';
        }
    }

    public function images()
    {
        return $this->hasMany(ProductImage::class, 'product_id');
    }
}
