<?php

namespace App\Models;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var string[]
     */
    protected $fillable = array('name', 'mobile', 'email', 'image', 'type', 'password', 'status', 'market_link', 'commercial_image', 'verification_code', 'verification_status', 'wallet', 'points');


    public function favourites()
    {
        return $this->belongsToMany(Product::class, 'favourites', 'user_id', 'product_id');
    }
    public function carts()
    {
        return $this->belongsToMany(Product::class, 'carts', 'user_id', 'product_id')->withPivot('count', 'total_price', 'id');
    }

    public function point_carts()
    {
        return $this->belongsToMany(PointProduct::class, 'point_carts', 'user_id', 'point_product_id')->withPivot('count', 'total_points', 'id');
    }

    public function notifications()
    {
        return $this->hasMany(Notification::class, 'user_id');
    }


    public function setImageAttribute()
    {
        $file = request()->file('image');
        $destinationPath = 'images/users/';
        $filename = time() . '.' . $file->getClientOriginalExtension();
        $file->move($destinationPath, $filename);
        $this->attributes['image'] = $filename;
    }

    public function getImageAttribute()
    {

        if (isset($this->attributes['image'])) {
            return asset('images/users/') . '/' . $this->attributes['image'];
        }
        return asset('logo.png');
    }

    public function setCommercialImageAttribute()
    {
        $file = request()->file('commercial_image');
        $destinationPath = 'images/users/';
        $filename = time() . '.' . $file->getClientOriginalExtension();
        $file->move($destinationPath, $filename);
        $this->attributes['commercial_image'] = $filename;
    }

    public function getCommercialImageAttribute()
    {

        if (isset($this->attributes['commercial_image'])) {
            return asset('images/users/') . '/' . $this->attributes['commercial_image'];
        }
        return asset('logo.png');
    }


    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];
}
